diff --git Charm/ApplicationCore.cpp Charm/ApplicationCore.cpp
index bf4832f..29f6a81 100644
--- Charm/ApplicationCore.cpp
+++ Charm/ApplicationCore.cpp
@@ -173,11 +173,13 @@ ApplicationCore::ApplicationCore( QObject* parent )
              SLOT(slotQuitApplication()) );
 
     m_actionAboutDialog.setText( tr( "About Charm" ) );
+    m_actionAboutDialog.setMenuRole(QAction::AboutRole);
     connect( &m_actionAboutDialog, SIGNAL(triggered()),
              &mainView(),  SLOT(slotAboutDialog()) );
 
     m_actionPreferences.setText( tr( "Preferences" ) );
     m_actionPreferences.setIcon( Data::configureIcon() );
+    m_actionPreferences.setMenuRole(QAction::PreferencesRole);
     connect( &m_actionPreferences, SIGNAL(triggered(bool)),
              &mainView(),  SLOT(slotEditPreferences(bool)) );
     m_actionPreferences.setEnabled( true );
@@ -275,7 +277,7 @@ void ApplicationCore::createWindowMenu( QMenuBar *menuBar )
     menu->addAction( &m_actionActivityReport );
     menu->addAction( &m_actionWeeklyTimesheetReport );
     menu->addAction( &m_actionMonthlyTimesheetReport );
-#ifndef Q_OS_OSX
+#if !defined(Q_OS_OSX) && !defined(Q_OS_MAC)
     menu->addSeparator();
 #endif
     menu->addAction( &m_actionPreferences );
@@ -292,7 +294,7 @@ void ApplicationCore::createFileMenu( QMenuBar *menuBar )
     menu->addAction( &m_actionSyncTasks );
     menu->addAction( &m_actionImportTasks );
     menu->addAction( &m_actionExportTasks );
-#ifndef Q_OS_OSX
+#if !defined(Q_OS_OSX) && !defined(Q_OS_MAC)
     menu->addSeparator();
 #endif
     menu->addAction( &m_actionQuit );
diff --git Charm/Charm.cpp Charm/Charm.cpp
index cc05cbe..19e03f7 100644
--- Charm/Charm.cpp
+++ Charm/Charm.cpp
@@ -38,9 +38,10 @@
 
 static ApplicationCore* createApplicationCore()
 {
-#ifdef Q_OS_OSX
-    return new MacApplicationCore;
-#endif
+// #if defined(Q_OS_OSX) || defined(Q_OS_MAC)
+//     // this seems to disable (menu) shortcuts...
+//     return new MacApplicationCore;
+// #endif
     return new ApplicationCore;
 }
 
@@ -71,6 +72,9 @@ int main ( int argc, char** argv )
 
     try {
         QApplication app( argc, argv );
+#if defined(Q_OS_MAC) || defined(Q_OS_OSX)
+        app.setAttribute(Qt::AA_DontShowIconsInMenus);
+#endif
         QScopedPointer<ApplicationCore> core( createApplicationCore() );
         QObject::connect( &app, SIGNAL(commitDataRequest(QSessionManager&)), core.data(), SLOT(commitData(QSessionManager&)) );
         QObject::connect( &app, SIGNAL(saveStateRequest(QSessionManager&)), core.data(), SLOT(saveState(QSessionManager&)) );
diff --git Charm/Data.cpp Charm/Data.cpp
index b5cf19e..b823d09 100644
--- Charm/Data.cpp
+++ Charm/Data.cpp
@@ -46,7 +46,7 @@ const QIcon& Data::charmTrayIcon()
     // On X11: pure-Qt apps get 22x22 from QSystemTrayIcon.
     // KDE apps seem to get 24x24 in KSystemTrayIcon via KIconLoader, which is actually better.
 
-#ifdef Q_OS_OSX
+#if !defined(Q_OS_OSX) && !defined(Q_OS_MAC)
     static const QString iconPath = QLatin1String(":/Charm/charmtray_mac.png");
 #else
     static const QString iconPath = QLatin1String(":/Charm/charmtray22.png");
@@ -65,7 +65,7 @@ const QIcon& Data::charmTrayActiveIcon()
     // On X11: pure-Qt apps get 22x22 from QSystemTrayIcon.
     // KDE apps seem to get 24x24 in KSystemTrayIcon via KIconLoader, which is actually better.
 
-#ifdef Q_OS_OSX
+#if !defined(Q_OS_OSX) && !defined(Q_OS_MAC)
     static const QString iconPath = QLatin1String(":/Charm/charmtrayactive_mac.png");
 #else
     static const QString iconPath = QLatin1String(":/Charm/charmtrayactive22.png");
diff --git Charm/Idle/IdleDetector.cpp Charm/Idle/IdleDetector.cpp
index 4da8dd3..6380bb7 100644
--- Charm/Idle/IdleDetector.cpp
+++ Charm/Idle/IdleDetector.cpp
@@ -46,7 +46,7 @@ IdleDetector::IdleDetector( QObject* parent )
 IdleDetector* IdleDetector::createIdleDetector( QObject* parent )
 {
 #ifdef CHARM_IDLE_DETECTION
-#ifdef Q_OS_OSX
+#if defined(Q_OS_OSX) || defined(Q_OS_MAC)
     return new MacIdleDetector( parent );
 #endif
 
diff --git Charm/Widgets/CharmWindow.cpp Charm/Widgets/CharmWindow.cpp
index 565d751..dcb9fcb 100644
--- Charm/Widgets/CharmWindow.cpp
+++ Charm/Widgets/CharmWindow.cpp
@@ -108,7 +108,7 @@ void CharmWindow::setWindowNumber( int number )
     delete m_shortcut;
     m_shortcut = new QShortcut( this );
     QKeySequence sequence( tr( "Ctrl+%1" ).arg( number ) );
-#ifdef Q_OS_OSX
+#if !defined(Q_OS_OSX) && !defined(Q_OS_MAC)
     m_shortcut->setKey( sequence );
 #endif
     m_shortcut->setContext( Qt::ApplicationShortcut );
diff --git Charm/Widgets/EventView.cpp Charm/Widgets/EventView.cpp
index e295d9d..76a4789 100644
--- Charm/Widgets/EventView.cpp
+++ Charm/Widgets/EventView.cpp
@@ -119,7 +119,7 @@ EventView::EventView( QToolBar* toolBar, QWidget* parent )
     m_actionDeleteEvent.setText( tr( "Delete Event..." ) );
     QList<QKeySequence> deleteShortcuts;
     deleteShortcuts << QKeySequence::Delete;
-#ifdef Q_OS_OSX
+#if !defined(Q_OS_OSX) && !defined(Q_OS_MAC)
     deleteShortcuts << Qt::Key_Backspace;
 #endif
     m_actionDeleteEvent.setShortcuts(deleteShortcuts);
